===========
Aggregation
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    DataFrame.count
    DataFrame.max
    DataFrame.max_horizontal
    DataFrame.mean
    DataFrame.mean_horizontal
    DataFrame.median
    DataFrame.min
    DataFrame.min_horizontal
    DataFrame.product
    DataFrame.quantile
    DataFrame.std
    DataFrame.sum
    DataFrame.sum_horizontal
    DataFrame.var
